Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(3755)

Unified Diff: chrome/browser/cocoa/tab_view_picker_table.h

Issue 2932009: Mac: Tweak content settings window. (Closed)
Patch Set: fffffffffffffffff Created 10 years, 5 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/cocoa/tab_view_picker_table.h
diff --git a/chrome/browser/cocoa/tab_view_picker_table.h b/chrome/browser/cocoa/tab_view_picker_table.h
index 43784d334761fa5427f0eaddae93ac61ac0abf32..75d943f31994cc19b0cc2c8103f670a164c72429 100644
--- a/chrome/browser/cocoa/tab_view_picker_table.h
+++ b/chrome/browser/cocoa/tab_view_picker_table.h
@@ -5,20 +5,25 @@
#import <Cocoa/Cocoa.h>
#import "base/cocoa_protocols_mac.h"
// TabViewPickerTable is an NSTableView that can be used to switch between the
// NSTabViewItems of an NSTabView. To use this, just create a
// TabViewPickerTable in Interface Builder and connect the |tabView_| outlet
// to an NSTabView. Now the table is automatically populated with the tab labels
// of the tab view, clicking the table updates the tab view, and switching
// tab view items updates the selection of the table.
-@interface TabViewPickerTable : NSTableView <NSTabViewDelegate,
- NSTableViewDelegate,
- NSTableViewDataSource> {
+@interface TabViewPickerTable : NSOutlineView <NSTabViewDelegate,
+ NSOutlineViewDelegate,
+ NSOutlineViewDataSource> {
@public
IBOutlet NSTabView* tabView_; // Visible for testing.
@private
id oldTabViewDelegate_;
+
+ // Shown above all the tab names. May be |nil|.
+ scoped_nsobject<NSString> heading_;
}
+@property (nonatomic, copy) NSString* heading;
@end
« no previous file with comments | « chrome/browser/cocoa/content_settings_dialog_controller.mm ('k') | chrome/browser/cocoa/tab_view_picker_table.mm » ('j') | no next file with comments »

Powered by Google App Engine
@@ -5,20 +5,25 @@
#import <Cocoa/Cocoa.h>
#import "base/cocoa_protocols_mac.h"
+#include "base/scoped_nsobject.h"
-// TabViewPickerTable is an NSTableView that can be used to switch between the
+// TabViewPickerTable is an NSOutlineView that can be used to switch between the
// NSTabViewItems of an NSTabView. To use this, just create a
// TabViewPickerTable in Interface Builder and connect the |tabView_| outlet
This is Rietveld 408576698